# Description

coming soon ...

# Installation

From [pypi.org](https://pypi.org/project/sturdy/):
```
pip install sturdy
```

From [test.pypi.org](https://test.pypi.org/project/sturdy/):
```
pip install -i https://test.pypi.org/simple/ sturdy
```


[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
